import { buttonVariants } from "@/components/ui/button";
import { Card } from "@/components/ui/card";
import { UserAvatar } from "@/components/user-avatar";
import { cn, formatTimeElapsed } from "@/lib/utils";
import Image from "next/image";
import { useRouter } from "next/navigation";
import { IGweet } from "../types";
import { GweetActions } from "./gweet-actions";
import { GweetOptions } from "./gweet-options";

export const Gweet = ({ gweet }: { gweet: IGweet }) => {
  const router = useRouter();

  return (
    <div
      tabIndex={0}
      onClick={() => router.push(`/${gweet.author.username}/status/${gweet.id}`)}
      className={cn(buttonVariants({ variant: "ghost" }), "flex flex-col flex-grow h-auto w-full text-left cursor-pointer items-start p-3 space-y-3")}
    >
      {/* TODO replyto */}
      {/* <div className="">
            {gweet?.replyToGweetId && (
              <div className="">
                <span className="">Replying to</span>
                <button
                  onClick={(e) => {
                    e.stopPropagation();
                    router.push(`/${gweet?.author.username}`);
                  }}
                  className=""
                >
                  @{gweet?.author.username}
                </button>
              </div>
            )}
          </div> */}
      <div className="flex flex-row h-auto w-full">
        <UserAvatar
          user={{ username: gweet.author.username, image: gweet.author.image }}
          className="h-10 w-10"
        />

        <div className="flex flex-col flex-grow space-y-3 ml-3 w-1">
          <div className="flex items-start">

            <div className="flex space-x-2 flex-grow">
              <h1 className="font-bold">{gweet.author.name}</h1>
              <h1 className="text-sky-500 text-sm">
                @{gweet.author.username}
              </h1>
              <span>·</span>
              <h1 className="text-gray-500 text-sm">
                {formatTimeElapsed(gweet.createdAt)}
              </h1>
            </div>

            <div className="ml-auto">
              <GweetOptions gweet={gweet} />
            </div>
          </div>

          <div className="flex flex-col flex-grow space-y-3 w-full">
            {gweet.content && <h1 className="break-words">{gweet.content}</h1>}

            {gweet.media.length > 0 && (
              <div className={`grid object-cover h-[600px] ${gweet.media.length === 1 ? "grid-cols-1"
                : gweet.media.length === 2 ? "grid-cols-2 gap-3"
                  : gweet.media.length === 3 || 4 ? "grid-cols-2 grid-rows-2 gap-3"
                    : ""
                }`}
              >
                {gweet.media.map((image, i) => {
                  const isFirstImage = gweet.media.length === 3 && i === 0;
                  return (
                    <Card key={i} className={`relative max-h-[600px] overflow-hidden ${isFirstImage ? "row-span-2" : ""}`}>
                      <Image
                        src={image.url as string}
                        alt="gweet image"
                        fill
                        className="object-cover rounded-lg"
                      />
                    </Card>
                  );
                })}
              </div>
            )}

            {/* TODO */}
            {/* {quoted_gweet && <QuotedGweet gweet={quoted_gweet} />} */}
          </div>
        </div>
      </div>

      <div className="flex justify-end flex-grow w-full" >
        <GweetActions gweet={gweet} />
      </div>
    </div>
  );
};